@@ -7,6 +7,8 @@ from .ContactDatabaseManager import ContactDatabaseManager
 from .GroupDatabaseManager import GroupDatabaseManager
 from .SmartqqMessageHandler import SmartqqMessageHandler
 from .Logger import logger
+from .MessageErrcodeException import MessageErrcodeException
+from .OnlineChecker import OnlineChecker
 
 
 class SmartqqClient:
@@ -80,6 +82,16 @@ class SmartqqClient:
         )
         return self.stopped
 
+    def message_preprocess(self, data):
+        message = data.json()
+        if ("retcode" in message) and message["retcode"] != 0:
+            if message["retcode"] == 103:
+                logger.info(OnlineChecker.check_online(self.login_data, self.session).content)
+            raise MessageErrcodeException
+        if "result" not in message:
+            raise MessageErrcodeException
+        return message["result"][0]
+
     def __init__(self, login_data=None, barcode_handler=None,
                  friend_message_handler=None, group_message_handler=None, passing_env=False,
                  login_done_handler=None, login_exception_handler=None,
@@ -99,6 +111,7 @@ class SmartqqClient:
             else self.default_group_message_handler
         )
         self.message_handler = SmartqqMessageHandler.print_all_handler(
+            message_preprocess=self.message_preprocess,
             friend_message_handler=self.friend_message_handler,
             group_message_handler=self.group_message_handler
         )
